<?php
$labels['mh_title'] = 'Message Highlights';
$labels['mh_matches'] = 'matches';
$labels['mh_color'] = 'color';
$labels['mh_delete'] = 'delete';
$labels['mh_delete_description'] = 'Delete this line';
$labels['mh_add'] = 'add row';
$labels['mh_add_description'] = 'Add an extra row beneath this row';
$labels['deleteconfirm'] = 'Do you really want to delete this rule?';

// these should never happen, but add anyways
$labels['headererror'] = 'Error in message rule';
$labels['inputempty'] = 'One or more of your matches are empty';
$labels['invalidcolor'] = 'Invalid color';

?>