<?php
$labels['mh_title'] = 'Berichten markeren';
$labels['mh_matches'] = 'bevat';
$labels['mh_color'] = 'kleur';
$labels['mh_delete'] = 'verwijderen';
$labels['mh_delete_description'] = 'Verwijder deze regel';
$labels['mh_add'] = 'regel toevoegen';
$labels['mh_add_description'] = 'Voeg een extra regel toe onder deze regel';
$labels['deleteconfirm'] = 'Wilt u deze regel echt verwijderen?';

// these should never happen, but add anyways
$labels['headererror'] = 'Fout in configuratie';
$labels['invalidcolor'] = 'Onjuiste kleur';

?>