<?php
$labels['mh_title'] = 'Nachrichtenmarkierung';
$labels['mh_matches'] = 'enthält';
$labels['mh_color'] = 'Farbe';
$labels['mh_delete'] = 'löschen';
$labels['mh_delete_description'] = 'Diese Regel löschen';
$labels['mh_add'] = 'hinzufügen';
$labels['mh_add_description'] = 'Eine Regel hinzufügen';
$labels['deleteconfirm'] = 'Möchten Sie diese Regel wirklich löschen?';

// these should never happen, but add anyways
$labels['headererror'] = 'Diese Regel ist fehlerhaft';
$labels['inputempty'] = 'Ein oder mehrere Treffer sind leer';
$labels['invalidcolor'] = 'Ungültige Farbauswahl';
?>
