<?php
$labels['mh_title'] = 'Mise en valeur des messages';
$labels['mh_matches'] = 'Correspondance';
$labels['mh_color'] = 'Couleur';
$labels['mh_delete'] = 'Supprimer';
$labels['mh_delete_description'] = 'Supprimer cette ligne';
$labels['mh_add'] = 'Ajouter une ligne';
$labels['mh_add_description'] = 'Ajouter une ligne supplémentaire sous cette ligne';
$labels['deleteconfirm'] = 'Voulez-vous réellement supprimer cette règle ?';

// Cela ne devrait jamais arriver, mais on ne sait jamais
$labels['headererror'] = 'Erreur dans la règle sur les messages';
$labels['inputempty'] = 'Une ou plusieurs de vos correspondances sont vides';
$labels['invalidcolor'] = 'Couleur invalide';

?>